@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2022-11-11
+# Release 2022-11-12
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.6.1
+MAKERESOLVEDEB_VERSION=1.6.2
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -512,7 +512,7 @@ installer_extract_native() {
 	echo "[ERROR] DaVinci Resolve installer archive is not executable"
 	exit 1
     fi
-    NUMEXTRACT=$(./${INSTALLER_ARCHIVE} -i -y -n -C ${UNPACK_DIR_ABS} | grep "^Copied " -c)
+    NUMEXTRACT=$(SKIP_PACKAGE_CHECK=1 ./${INSTALLER_ARCHIVE} -i -y -n -C ${UNPACK_DIR_ABS} | grep "^Copied " -c)
     echo "Found ${NUMEXTRACT} objects"
     if [[ -z "$(ls -A ${UNPACK_DIR})" ]];
     then
@@ -680,7 +680,7 @@ esac
 close_deb
 
 if [[ -z "$CI_TEST" ]]; then
-    echo "Creating Debian package"
+    echo "Creating Debian package (This can take a while. Do not interrupt)"
     if ! fakeroot dpkg-deb -b ${DEB_DIR} ${DEB_DIR}.deb;
     then
 	ERRORS=$((ERRORS+1))
